=======
History
=======

0.1.2 (2017-08-21)
------------------

* bump version testing

0.1.1 (2017-08-21)
------------------

* Support for ``aws_instance`` and ``vsphere_virtual_machine`` Terraform resources.
* Ansible parameters available: ansible_user, ansible_host, ansible_ssh_private_key_file
* Define Terraform resource to ansible group.

0.1.0 (2017-08-10)
------------------

* First release on PyPI.
